pub enum LogicalPlanLite {
Scan {
table: String,
predicate: Option<String>,
projection: Vec<String>,
},
Aggregate {
input: Box<LogicalPlanLite>,
group_by: Vec<String>,
aggregates: Vec<AggregateExpr>,
},
Join {
left: Box<LogicalPlanLite>,
right: Box<LogicalPlanLite>,
on: Vec<JoinKey>,
},
Sort {
input: Box<LogicalPlanLite>,
keys: Vec<SortKey>,
limit: Option<usize>,
},
Limit {
input: Box<LogicalPlanLite>,
limit: usize,
},
}Expand description
The simplified logical IR distribute lowers onto tablets.
This is the seam documented at the module level: the DataFusion integration wave lowers real DataFusion plans onto this enum; this wave plans from it directly.
Variants
Scan
Base-table scan with an optional opaque predicate and projection.
Fields
Aggregate
Grouped aggregation.
Fields

input: Box<LogicalPlanLite>Input subtree.

aggregates: Vec<AggregateExpr>Aggregate expressions.
Join
Equi-join.
Fields

left: Box<LogicalPlanLite>Left input subtree.

right: Box<LogicalPlanLite>Right input subtree.
Sort
Sort with an optional limit (ORDER BY ... [LIMIT k]).
Fields

input: Box<LogicalPlanLite>Input subtree.
Limit
Limit without an ordering.